@@ -1,5 +1,5 @@
 package Mail::DMARC::Report::Store;
-our $VERSION = '1.20170911'; # VERSION
+our $VERSION = '1.20211209';
 use strict;
 use warnings;
 
@@ -22,6 +22,11 @@ sub retrieve {
     return $self->backend->retrieve(@_);
 }
 
+sub next_todo {
+    my $self = shift;
+    return $self->backend->next_todo(@_);
+}
+
 sub retrieve_todo {
     my $self = shift;
     return $self->backend->retrieve_todo(@_);
@@ -45,8 +50,6 @@ sub backend {
 
 1;
 
-# ABSTRACT: persistent storage broker for reports
-
 __END__
 
 =pod
@@ -57,7 +60,7 @@ Mail::DMARC::Report::Store - persistent storage broker for reports
 
 =head1 VERSION
 
-version 1.20170911
+version 1.20211209
 
 =head1 SYNOPSIS
 
@@ -81,11 +84,15 @@ Matt Simerson <msimerson@cpan.org>
 
 Davide Migliavacca <shari@cpan.org>
 
+=item *
+
+Marc Bradshaw <marc@marcbradshaw.net>
+
 =back
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2015 by Matt Simerson.
+This software is copyright (c) 2021 by Matt Simerson.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
